@@ -145,9 +145,9 @@ class LogUriError(EmrError):
 class MasterDNSNotAvailableError(EmrError):
 
     """
-    Cannot get public dns of master node on the cluster.
+    Cannot get dns of master node on the cluster.
     """
-    fmt = 'Cannot get Public DNS of master node on the cluster. '\
+    fmt = 'Cannot get DNS of master node on the cluster. '\
           ' Please try again after some time.'
 
 
@@ -334,3 +334,8 @@ class UnsupportedCommandWithReleaseError(EmrError):
 
     fmt = ("aws: error: {command} is not supported with "
            "'{release_label}' release.")
+
+class MissingAutoScalingRoleError(EmrError):
+
+    fmt = ("aws: error: Must specify --auto-scaling-role when configuring an "
+           "AutoScaling policy for an instance group.")
